@@ -42,25 +42,25 @@ impl<'de> de::Visitor<'de> for SimpleVisitor {
 /// Methods used to encode and decode the KEY.
 pub trait KeyEnDe: Serialize + DeserializeOwned {
     /// Encode original key type to bytes.
-    #[cfg(all(feature = "cbor_ende", not(feature = "bcs_ende")))]
+    #[cfg(all(feature = "cbor_codec", not(feature = "bcs_codec")))]
     fn encode(&self) -> RawBytes {
         serde_cbor::to_vec(self).unwrap().into_boxed_slice()
     }
 
     /// Encode original key type to bytes.
-    #[cfg(all(feature = "bcs_ende", not(feature = "cbor_ende")))]
+    #[cfg(all(feature = "bcs_codec", not(feature = "cbor_codec")))]
     fn encode(&self) -> RawBytes {
         bcs::to_bytes(self).unwrap().into_boxed_slice()
     }
 
     /// Decode from bytes to the original key type.
-    #[cfg(all(feature = "cbor_ende", not(feature = "bcs_ende")))]
+    #[cfg(all(feature = "cbor_codec", not(feature = "bcs_codec")))]
     fn decode(bytes: &[u8]) -> Result<Self> {
         serde_cbor::from_slice(bytes).c(d!())
     }
 
     /// Decode from bytes to the original key type.
-    #[cfg(all(feature = "bcs_ende", not(feature = "cbor_ende")))]
+    #[cfg(all(feature = "bcs_codec", not(feature = "cbor_codec")))]
     fn decode(bytes: &[u8]) -> Result<Self> {
         bcs::from_bytes(bytes).c(d!())
     }
@@ -69,25 +69,25 @@ pub trait KeyEnDe: Serialize + DeserializeOwned {
 /// Methods used to encode and decode the VALUE.
 pub trait ValueEnDe: Serialize + DeserializeOwned {
     /// Encode original key type to bytes.
-    #[cfg(all(feature = "cbor_ende", not(feature = "bcs_ende")))]
+    #[cfg(all(feature = "cbor_codec", not(feature = "bcs_codec")))]
     fn encode(&self) -> RawBytes {
         serde_cbor::to_vec(self).unwrap().into_boxed_slice()
     }
 
     /// Encode original key type to bytes.
-    #[cfg(all(feature = "bcs_ende", not(feature = "cbor_ende")))]
+    #[cfg(all(feature = "bcs_codec", not(feature = "cbor_codec")))]
     fn encode(&self) -> RawBytes {
         bcs::to_bytes(self).unwrap().into_boxed_slice()
     }
 
     /// Decode from bytes to the original key type.
-    #[cfg(all(feature = "cbor_ende", not(feature = "bcs_ende")))]
+    #[cfg(all(feature = "cbor_codec", not(feature = "bcs_codec")))]
     fn decode(bytes: &[u8]) -> Result<Self> {
         serde_cbor::from_slice(bytes).c(d!())
     }
 
     /// Decode from bytes to the original key type.
-    #[cfg(all(feature = "bcs_ende", not(feature = "cbor_ende")))]
+    #[cfg(all(feature = "bcs_codec", not(feature = "cbor_codec")))]
     fn decode(bytes: &[u8]) -> Result<Self> {
         bcs::from_bytes(bytes).c(d!())
     }
@@ -97,12 +97,12 @@ impl<T: Serialize + DeserializeOwned> KeyEnDe for T {}
 impl<T: Serialize + DeserializeOwned> ValueEnDe for T {}
 
 // used to encode the deref value of `Option<Box<[u8]>>`
-#[cfg(all(feature = "cbor_ende", not(feature = "bcs_ende")))]
+#[cfg(all(feature = "cbor_codec", not(feature = "bcs_codec")))]
 pub(crate) fn encode_optioned_bytes(v: &Option<&[u8]>) -> RawBytes {
     serde_cbor::to_vec(v).unwrap().into_boxed_slice()
 }
 
-#[cfg(all(feature = "bcs_ende", not(feature = "cbor_ende")))]
+#[cfg(all(feature = "bcs_codec", not(feature = "cbor_codec")))]
 pub(crate) fn encode_optioned_bytes(v: &Option<&[u8]>) -> RawBytes {
     bcs::to_bytes(v).unwrap().into_boxed_slice()
 }
